IntoIter

Struct IntoIter 

1.0.0 ยท Source
pub struct IntoIter<A> { /* private fields */ }
An iterator over the value in Some variant of an Option.

The iterator yields one value if the Option is a Some, otherwise none.

This struct is created by the Option::into_iter function.