pub struct IntoIter<A> { /* private fields */ }Expand description
An iterator over the value in Some variant of an Option.
The iterator yields one value if the Option is a Some, otherwise none.
This struct is created by the Option::into_iter function.